ansible-playbook

## Name

ansible-playbook — run an ansible playbook

## Synopsis

ansible-playbook <filename.yml> … [options]

## DESCRIPTION

Ansible playbooks are a configuration and multinode deployment system. Ansible-playbook is the tool used to run them. See the project home page (link below) for more information.

## ARGUMENTS

filename.yml
  The names of one or more YAML format files to run as ansible playbooks.

## OPTIONS

-i PATH, --inventory=PATH
  The PATH to the inventory hosts file, which defaults to /etc/ansible/hosts.
-M DIRECTORY, --module-path=DIRECTORY
  The DIRECTORY to load modules from. The default is /usr/share/ansible.
-f NUM, --forks=NUM
  Level of parallelism. NUM is specified as an integer, the default is 5.
-k, --ask-pass
  Prompt for the SSH password instead of assuming key-based authentication with ssh-agent.
-T SECONDS, --timeout=SECONDS
  Connection timeout to use when trying to talk to hosts, in SECONDS.

## ENVIRONMENT

The following environment variables may specified.

ANSIBLE_HOSTS  — Override the default ansible hosts file

ANSIBLE_LIBRARY — Override the default ansible module library path

## AUTHOR

Ansible was originally written by Michael DeHaan. See the AUTHORS file for a complete list of contributors.

## COPYRIGHT

Copyright © 2012, Michael DeHaan

Ansible is released under the terms of the GPLv3 License.

## SEE ALSO

ansible(1)

Extensive documentation as well as IRC and mailing list info is available on the ansible home page: https://ansible.github.com/